@@ -47,6 +47,7 @@ PyInterpreterState* omniPy::pyInterpreter;
 PyObject* omniPy::py_omnipymodule;	// The _omnipy extension
 PyObject* omniPy::py_pseudoFns;         //  pseudoFns
 PyObject* omniPy::py_policyFns;         //  policyFns
+PyObject* omniPy::py_callInfoFns;       //  callInfoFns
 PyObject* omniPy::pyCORBAmodule;	// The CORBA module
 PyObject* omniPy::pyCORBAsysExcMap;	//  The system exception map
 PyObject* omniPy::pyCORBAORBClass;	//  ORB class
@@ -207,7 +208,7 @@ extern "C" {
   }
 
 #define OMNIPY_ATTR(x) \
-  PyObject_GetAttrString(omniPy::pyomniORBmodule, (char*)x);
+  PyObject_GetAttrString(omniPy::pyomniORBmodule, (char*)x)
 
   static PyObject*
   omnipy_registerPyObjects(PyObject* self, PyObject* args)
@@ -490,20 +491,10 @@ extern "C" {
     Py_ssize_t size;
     int        endian = -1;
     
-#if (PY_VERSION_HEX < 0x03000000)
-
-    if (!PyArg_ParseTuple(args, (char*)"Os#|i",
-			  &desc, &encap, &size, &endian))
-      return 0;
-
-#else
-
     if (!PyArg_ParseTuple(args, (char*)"Oy#|i",
 			  &desc, &encap, &size, &endian))
       return 0;
 
-#endif
-
     if (endian > 1 || endian < -1) {
       PyErr_SetString(PyExc_ValueError,
 		      "argument 3: endian must be 0 or 1");
@@ -648,11 +639,7 @@ extern "C" {
     omniPy::initServant(d);
 
     // Set up the C++ API singleton
-#if (PY_VERSION_HEX < 0x03000000)
-    PyObject* api = PyCObject_FromVoidPtr((void*)&omniPy::cxxAPI, 0);
-#else
     PyObject* api = PyCapsule_New((void*)&omniPy::cxxAPI, "_omnipy.API", 0);
-#endif
     PyDict_SetItemString(d, (char*)"API", api);
     Py_DECREF(api);
 
@@ -668,6 +655,12 @@ extern "C" {
     PyDict_SetItemString(d, (char*)"policyFns", omniPy::py_policyFns);
     Py_DECREF(omniPy::py_policyFns);
 
+    // Empty dict for external transport modules to register
+    // additional call info functions.
+    omniPy::py_callInfoFns = PyDict_New();
+    PyDict_SetItemString(d, (char*)"callInfoFns", omniPy::py_callInfoFns);
+    Py_DECREF(omniPy::py_callInfoFns);
+
     // Codesets
     omniPy::ncs_c_utf_8 = omniCodeSet::getNCS_C("UTF-8");
 
@@ -675,19 +668,6 @@ extern "C" {
     omniInitialiser::install(&the_omni_python_initialiser);
   }
 
-#if (PY_VERSION_HEX < 0x03000000)
-
-  void DLL_EXPORT init_omnipy()
-  {
-    // Make sure Python is running multi-threaded
-    PyEval_InitThreads();
-
-    PyObject* m = Py_InitModule((char*)"_omnipy", omnipy_methods);
-    initModule(m);
-  }
-
-#else
-
   static struct PyModuleDef omnipymodule = {
     PyModuleDef_HEAD_INIT,
     "_omnipy",
@@ -703,16 +683,21 @@ extern "C" {
   PyMODINIT_FUNC
   PyInit__omnipy(void)
   {
+#if (PY_VERSION_HEX < 0x03070000)
     // Make sure Python is running multi-threaded
     PyEval_InitThreads();
+#endif
 
     PyObject* m = PyModule_Create(&omnipymodule);
     if (!m)
       return 0;
 
+#if (PY_VERSION_HEX >= 0x030d0000) && defined(Py_GIL_DISABLED)
+    // Declare that we can run without the GIL
+    PyUnstable_Module_SetGIL(m, Py_MOD_GIL_NOT_USED);
+#endif
+
     initModule(m);
     return m;
   }
-
-#endif
 }
